@@ -14,6 +14,11 @@ class SolanaCurrencyUnit(Enum):
     SOL = "sol"
 
 
+class SolanaNFTUploadMethod(Enum):
+    S3 = "S3"
+    LINK = "LINK"
+
+
 class TheBlockchainAPIResource:
 
     __url = "https://api.theblockchainapi.com/v1/"
@@ -281,7 +286,8 @@ class TheBlockchainAPIResource:
         nft_symbol: str = str(),
         nft_description: str = str(),
         nft_url: str = str(),
-        nft_metadata: dict = None
+        nft_metadata: dict = None,
+        nft_upload_method: SolanaNFTUploadMethod = SolanaNFTUploadMethod.S3
     ) -> dict:
         """
         More info: https://docs.theblockchainapi.com/#tag/Solana-NFT/paths/~1v1~1solana~1nft/post
@@ -294,6 +300,8 @@ class TheBlockchainAPIResource:
         :param nft_description: The description of the NFT
         :param nft_url: The image of the NFT
         :param nft_metadata: The metadata of the NFT
+        :param nft_upload_method: The upload method of the NFT. Upload the URL to S3 and embed it. Or save it directly
+        to the NFT
         :return:
         """
         if nft_metadata is None:
@@ -306,7 +314,8 @@ class TheBlockchainAPIResource:
             "nft_symbol": nft_symbol,
             "nft_description": nft_description,
             "nft_url": nft_url,
-            "nft_metadata": nft_metadata
+            "nft_metadata": nft_metadata,
+            "nft_upload_method": nft_upload_method
         }
         if derivation_path is not None:
             payload['derivation_path'] = derivation_path
